@@ -44,38 +44,54 @@ class AttributeDescriptor(object):
                     type_checks.append(typ)
 
             for typ in type_checks:
-                if isinstance(val, typ):
+                if not isinstance(typ, TypeProxy) and isinstance(val, typ):
                     ok = True
                     break
                 elif hasattr(typ, "isLiteralClass"):
                     try:
                         validator = typ(val)
+                        validator.validate()
                     except Exception as e:
                         errors.append("Failed to coerce to '{0}': {1}".format(typ, e))
                         pass
                     else:
-                        validator.validate()
                         ok = True
                         break
                 elif util.safe_issubclass(typ, ProtocolBase):
                     # force conversion- thus the val rather than validator assignment
                     try:
                         val = typ(**util.coerce_for_expansion(val))
+                        val.validate()
                     except Exception as e:
                         errors.append("Failed to coerce to '{0}': {1}".format(typ, e))
                         pass
                     else:
-                        val.validate()
                         ok = True
                         break
                 elif util.safe_issubclass(typ, wrapper_types.ArrayWrapper):
                     try:
                         val = typ(val)
+                        val.validate()
                     except Exception as e:
                         errors.append("Failed to coerce to '{0}': {1}".format(typ, e))
                         pass
                     else:
+                        ok = True
+                        break
+                elif isinstance(typ, TypeProxy):
+                    try:
+                        # handle keyword expansion according to expected types
+                        # using keywords like oneOf, value can be an object, array or literal
+                        val = util.coerce_for_expansion(val)
+                        if isinstance(val, dict):
+                            val = typ(**val)
+                        else:
+                            val = typ(val)
                         val.validate()
+                    except Exception as e:
+                        errors.append("Failed to coerce to '{0}': {1}".format(typ, e))
+                        pass
+                    else:
                         ok = True
                         break
 
@@ -109,7 +125,11 @@ class AttributeDescriptor(object):
             val.validate()
 
         elif isinstance(info["type"], TypeProxy):
-            val = info["type"](val)
+            val = util.coerce_for_expansion(val)
+            if isinstance(val, dict):
+                val = info["type"](**val)
+            else:
+                val = info["type"](val)
 
         elif isinstance(info["type"], TypeRef):
             if not isinstance(val, info["type"].ref_class):
