@@ -22,6 +22,7 @@ def MakeLiteral(name, typ, value, **properties):
     return klass(value)
 
 
+@functools.total_ordering
 class LiteralValue(object):
     """Docstring for LiteralValue """
 
@@ -30,9 +31,9 @@ class LiteralValue(object):
     def __init__(self, value, typ=None):
         """@todo: to be defined
 
-      :value: @todo
+        :value: @todo
 
-      """
+        """
         if isinstance(value, LiteralValue):
             self._value = value._value
         else:
@@ -84,12 +85,16 @@ class LiteralValue(object):
                 validator(paramval, self._value, info)
 
     def __eq__(self, other):
+        if isinstance(other, LiteralValue):
+            return self._value == other._value
         return self._value == other
 
     def __hash__(self):
         return hash(self._value)
 
     def __lt__(self, other):
+        if isinstance(other, LiteralValue):
+            return self._value < other._value
         return self._value < other
 
     def __int__(self):
